Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(991)

Unified Diff: chrome/browser/prefs/in_memory_pref_store.h

Issue 5204006: Renamed DefaultPrefStore into InMemoryPrefStore because it can be used in further contexts. (Closed) Base URL: http://git.chromium.org/git/chromium.git@trunk
Patch Set: Rebased Created 10 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/prefs/default_pref_store.cc ('k') | chrome/browser/prefs/in_memory_pref_store.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/prefs/in_memory_pref_store.h
diff --git a/chrome/browser/prefs/default_pref_store.h b/chrome/browser/prefs/in_memory_pref_store.h
similarity index 50%
rename from chrome/browser/prefs/default_pref_store.h
rename to chrome/browser/prefs/in_memory_pref_store.h
index 6378acaf75c307dc94c668229403855dbc3b6bb8..25588149a139299cc78e608e7165f352c4f14850 100644
--- a/chrome/browser/prefs/default_pref_store.h
+++ b/chrome/browser/prefs/in_memory_pref_store.h
@@ -2,20 +2,21 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_PREFS_DEFAULT_PREF_STORE_H_
-#define CHROME_BROWSER_PREFS_DEFAULT_PREF_STORE_H_
+#ifndef CHROME_BROWSER_PREFS_IN_MEMORY_PREF_STORE_H_
+#define CHROME_BROWSER_PREFS_IN_MEMORY_PREF_STORE_H_
#pragma once
#include "base/basictypes.h"
#include "base/scoped_ptr.h"
#include "chrome/common/pref_store.h"
-// This PrefStore keeps track of default preference values set when a
-// preference is registered with the PrefService.
-class DefaultPrefStore : public PrefStore {
+// This PrefStore keeps track of preference values in memory and can be used,
+// e.g., for default preference values set when a preference is registered with
+// the PrefService.
+class InMemoryPrefStore : public PrefStore {
public:
- DefaultPrefStore();
- virtual ~DefaultPrefStore();
+ InMemoryPrefStore();
+ virtual ~InMemoryPrefStore();
// PrefStore methods:
virtual DictionaryValue* prefs() const;
@@ -25,7 +26,7 @@ class DefaultPrefStore : public PrefStore {
// The default preference values.
scoped_ptr<DictionaryValue> prefs_;
- DISALLOW_COPY_AND_ASSIGN(DefaultPrefStore);
+ DISALLOW_COPY_AND_ASSIGN(InMemoryPrefStore);
};
-#endif // CHROME_BROWSER_PREFS_DEFAULT_PREF_STORE_H_
+#endif // CHROME_BROWSER_PREFS_IN_MEMORY_PREF_STORE_H_
« no previous file with comments | « chrome/browser/prefs/default_pref_store.cc ('k') | chrome/browser/prefs/in_memory_pref_store.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698